@@ -1,3 +1,7 @@
+/*******************************************
+ *	Builtin functions
+ *******************************************/
+
 #include "wily.h"
 #include "view.h"
 #include <errno.h>
@@ -6,12 +10,6 @@
 /* Each of these functions takes a View used as the context
  * of the command, and an argument.  The argument may be null.
  */
-typedef struct Cmd Cmd;
-struct Cmd {
-	char	*name;
-	void	(*cmd)(View *, char *);
-};
-
 /*
  * If given arguments, Kill all the external processes matching
  * the arguments.
@@ -213,6 +211,12 @@ new(View *v, char *arg) {
 		data_open(label, true);
 }
 
+typedef struct Cmd Cmd;
+struct Cmd {
+	char	*name;
+	void	(*cmd)(View *, char *);
+};
+
 /* _Must_ be kept in sorted order, we use bsearch on it */
 static Cmd builtins[] = {
 	{"Anchor", anchor},
