@@ -1,3 +1,7 @@
+/*******************************************
+ *	Handle double-click, etc.
+ *******************************************/
+
 #include "wily.h"
 #include "text.h"
 #include <ctype.h>
