@@ -1,3 +1,7 @@
+/*******************************************
+ *	Cursor bitmaps
+ *******************************************/
+
 /* Copyright (c) 1992 AT&T - All rights reserved. */
 #include <u.h>
 #include <libc.h>
