@@ -1,3 +1,7 @@
+/*******************************************
+ *	Data methods
+ *******************************************/
+
 #include "wily.h"
 #include "data.h"
 #include <errno.h>
@@ -17,7 +21,7 @@ data_tag(Data*d){
 /* Return the names in directory 'd', or 0 */
 char**
 data_names(Data*d){
-	return d?d->names:0;
+	return d ? d->names : 0;
 }
 
 /* Return true if 'd' should have its resize box filled in */
