@@ -1,3 +1,7 @@
+/*******************************************
+ *	Read and format directories
+ *******************************************/
+
 #include "wily.h"
 #include "data.h"
 
@@ -35,7 +39,7 @@ dirnames (DIR *dirp, char *path) {
 
 	/* Read the directory into a big buffer */
 
-	rewinddir(dirp);	/* Workaround for possible FreeBSD bug. */
+	rewinddir(dirp);	/* Workaround for FreeBSD. */
 
 	list = (char**) salloc(maxnames * sizeof(char*));
 
