@@ -1,3 +1,7 @@
+/*******************************************
+ *	~ and $ expand and contract
+ *******************************************/
+
 #include "wily.h"
 #include <stdlib.h>
 #include <sys/types.h>
