@@ -1,3 +1,7 @@
+/*******************************************
+ *	fork, setup environment, exec children
+ *******************************************/
+
 #include "wily.h"
 #include <ctype.h>
 #include <sys/wait.h>
@@ -135,9 +139,9 @@ pipe_views(char**cmd, View**vout, View**vin) {
 	View*vpipe;
 	
 	op = **cmd;
+	*vout = 0;
+	*vin = 0;
 	if(!( op == '|' || op == '<' || op == '>')){
-		*vout = 0;
-		*vin = 0;
 		return 0;
 	}
 	
