@@ -1,3 +1,7 @@
+/*******************************************
+ *	Data read/write files, directories
+ *******************************************/
+
 #include "wily.h"
 #include "data.h"
 
@@ -123,8 +127,8 @@ static int
 data_getdir(Data*d, char*label, char*path, Stat*buf) {
 	DIR*	dirp;
 	
-	if(!(dirp = opendir(path))) {
-		diag(path, "opendir [%s]", path);
+	if((dirp = opendir(path)) == NULL) {
+		diag(0, "opendir [%s]", path);
 		return -1;	/* failure - modify nothing */
 	}
 	
@@ -156,7 +160,7 @@ static int
 data_getfile(Data*d, char*label, char*path, Stat*buf) {
 	int	fd;
 	extern Bool utfHadNulls;
-	if(!(fd = open(path, O_RDONLY))) {
+	if((fd = open(path, O_RDONLY)) == -1) {
 		diag(path, "open [%s]", path);
 		return -1;	/* failure - modify nothing */
 	}
@@ -196,7 +200,9 @@ data_settag(Data*d, char *path) {
 	common = d->names? dirtools : filetools;
 	specific = tag_match(path);
 	
-	sprintf (buf, "%s | %s %s ", d->label, common, specific);
+	sprintf (buf, "%s %s | %s %s ", d->label, 
+		d->names? "Get":"", 
+		filetools, specific);
 	tag_set(d->tag, buf);
 }
 
