@@ -1,3 +1,7 @@
+/*******************************************
+ *	Handle keystroke events
+ *******************************************/
+
 #include "wily.h"
 #include "view.h"
 
@@ -76,7 +80,7 @@ static void
 deleteline(View*v){
 	Range del = v->sel;
 	
-	del.p0 = text_nl(v->t, del.p0, 0);
+	del.p0 = text_startOfLine(v->t, del.p0);
 	view_cut(v, del);
 }
 
