@@ -1,3 +1,7 @@
+/*******************************************
+ *	Handle mouse actions
+ *******************************************/
+
 #include "wily.h"
 #include "view.h"
 #include <ctype.h>
@@ -89,7 +93,7 @@ b2(View *v, Range r, Bool ischord) {
 
 	cmd = text_duputf(v->t, r);
 
-	if(ischord && ls) {
+	if(ischord && ls  && RLEN(ls->sel) < 200) {
 		Range	rarg;
 
 		rarg = view_expand(ls, ls->sel, notfilename);
