@@ -1,8 +1,11 @@
+/*******************************************
+ *	Expand abbreviations for pathnames
+ *******************************************/
+
 #include "wily.h"
 #include <pwd.h>
 
 static char*	gettilde(const char*s);
-static void	pathclean(char*path);
 
 /*
  * Expand 'orig' into 'dest', using 'expansion'.
@@ -43,74 +46,59 @@ label2path(char*path, char*label) {
 	case '/':	strcpy(path, label); break;
 	default:	sprintf(path, "%s%s", wilydir, label); break;
 	}
-	pathclean(path);
+	labelclean(path);
 }
 
 /*********************************************************
 	static functions
 *********************************************************/
 
-/* Clean up 'path' by removing components with '.' or '..' */
-static void
-pathclean(char*path){
-	/* todo */
-}
-
 /* Clean up 'label' by removing components with '.' or '..' */
 void
-labelclean(char*label){
-	Path	copy_path;
-	char	*path,*new_path;
-	char	c;
+labelclean(char*label) {
+	char	*slash, *from, *to, c;
+	char	*back;
 	
-	/* Make a copy of the source path since we may need to modify it. */
-	strcpy(copy_path, label);
-	path = copy_path;
-	new_path = label;
-	
-	/* leading component */
-	while (path[0] != '/' && path[0] != '\0') {
-		*new_path++ = *path++;
+	slash = strchr(label,'/');
+	if(slash) {
+		from = to = slash+1;
+	} else {
+		return;
 	}
 	
-	/* first slash */
-	if(path[0] == '/')
-		*new_path++ = *path++;
-	
-	/* Expand each slash-separated pathname component. */
-	while (*path != '\0') {
-		switch(path[0]){
-		case '/':
-			path++;
+	while (from[0] != '\0') {
+		assert(to[-1] == '/');
+		switch(from[0]){
+		case '/':		/* ignore "//" */
+			from++;
 			continue;
 		case '.':
-			switch(path[1]){
+			switch(from[1]){
 			case '\0':
-			case '/':	/* Ignore ".". */
-				path++;
+			case '/':		/* Ignore "./" */
+				from++;
 				continue;
 			case '.':
-				if (path[2] == '\0' || path[2] == '/') {
-					path += 2;
-					/* Ignore ".." at root. */
-					if (new_path == label + 1)
-						continue;
-					/* Handle ".." by backing up. */
-					while ((--new_path)[-1] != '/')
-						;
-					/* todo - handle $h/.. */
+				if (from[2] == '\0' || from[2] == '/') {
+					from += 2;
+					to[-1] = '\0';
+					back = strrchr(label, '/');
+					if(back){
+						to = back+1;
+					} else {
+						to[-1] ='/';
+					}
 					continue;
 				}
 			}
 		default:
-			; /* pass */
+			do {
+				c = (*to++ = *from++);
+			} while (c != '\0' && c != '/');
+			from--;
 		}
-		/* Safely copy the next pathname component. */
-		do {
-			c = *new_path++ = *path++;
-		} while (c != '\0' && c != '/');
 	}
-	*new_path='\0';
+	*to='\0';
 }
 
 static char*
