@@ -1,3 +1,7 @@
+/*******************************************
+ *	Declarations of major functions and macros
+ *******************************************/
+
 #ifndef SAM_CODE
 void	error(char *, ...);
 #endif
@@ -12,6 +16,8 @@ Range	text_expand		(Text *, Range, char *);
 ulong	text_startofword	(Text *, ulong);
 
 /* col.c */
+Tile*		tile_col			(Tile*);
+void		col_new			(View*v, char *arg);
 void		col_del		(Tile*);
 
 /* data.c */
@@ -63,7 +69,8 @@ View *	data_find			(char*);
 int		text_linenumber	(Text *t, ulong );
 Bool		text_findline		(Text *, Range *, ulong);
 Range	text_lastline		(Text *);
-ulong	text_nl			(Text *, ulong pos, int delta);
+ulong	text_nl			(Text *, ulong, int);
+ulong	text_startOfLine	(Text *, ulong);
 
 /* mouse.c */
 void		domouse			(View*, Mouse*);
@@ -169,11 +176,8 @@ void		text_formatdir		(Text *t, char**);
 
 /* tile.c */
 Bool		tile_hidden		(Tile*tile);
-Bool		tile_isdirty		(Tile*tile);
-void		col_new			(View*v, char *arg);
+View*	tile_body			(Tile*tile);
 void		ereshaped		(Rectangle);
-View*	tile_body			(Tile*);
-Tile*		tile_col			(Tile*);
 void		tile_del			(Tile *);
 void		tile_grow			(Tile *, int );
 void		tile_move		(Tile *, Point);
@@ -221,14 +225,18 @@ void		cleanup_and_die	(int);
 Rstring 	utf2rstring		(char*utf);
 
 /* vgeom.c */
+void		filled			(View*, Range );
+void		extend_selection	(View*, Range );
 void		view_fillbutton	(View*v, Fcode f);
 void 	fill				(View*);
+void 	view_setscroll		(View*);
 int		snapheight		(View*v, int h);
 void		view_reshaped	(View*, Rectangle);
 int		view_lastlinepos	(View*v);
 int		view_stripwhitespace (View*v);
 
 /* view.c */
+void		view_getdot		(View *v, char*buf, Bool isLine);
 void		view_paste		(View*v);
 Range	view_expand		(View *v, Range r, char *s);
 View*	view_new		(Font *, Bool, Text *, Tile *);
