@@ -1,3 +1,7 @@
+/*******************************************
+ *	Display scroll_bars
+ *******************************************/
+
 #include "wily.h"
 
 static Bitmap *dkgrey_o, *dkgrey_e;
