@@ -1,3 +1,7 @@
+/*******************************************
+ *	Search in text
+ *******************************************/
+
 #include "wily.h"
 #include "text.h"
 
@@ -5,55 +9,15 @@ static char	*endword = "[^a-zA-Z0-9][^a-zA-Z0-9|]*";
 static char	*startword = "[^a-zA-Z0-9]";
 static char 	*special = ".*+?(|)\\[]^$";
 
-/*
- * Strip trailing slash from a regexp, if present and not escaped.
- * WARNING: This code can reference the character
- * immediately preceding its argument, so use with care.
+static Bool	findend(Text *t, Range *r, char *addr, Range dot);
+static Rstring	word(Rstring s);
+static Rstring	literal(Rstring s);
+static void	strip_re_slash(char *re);
+
+/* Look for the text in 'dot'.
+ * If found, set '*r' and return true,
+ * otherwise return false.
  */
-static void
-strip_re_slash(char *re) {
-	if ((re = strrchr(re, '/')) && re[1] == '\0' && re[-1] != '\\')
-		re[0] = '\0';
-}
-
-static Rstring
-literal(Rstring s)
-{
-	Rstring	s2;
-	Rune	*r;
-	
-	/* quote any special characters in 's' */
-	s2.r0 = s2.r1 = (Rune*)salloc(RSLEN(s)*2*sizeof(Rune));
-	for (r = s.r0; r < s.r1; r++){
-		if(utfrune(special, *r))
-			*s2.r1++ = '\\';
-		*s2.r1++ = *r;
-	}
-	return s2;
-}
-
-static Rstring
-word(Rstring s)
-{
-	Rstring	s2;
-	Rune	*r;
-	int	nrunes;
-	
-	nrunes = RSLEN(s)*2 +strlen(startword) + strlen(endword);
-	s2.r0 = s2.r1 = (Rune*)salloc(nrunes*sizeof(Rune));
-
-	s2.r1 += utftotext(s2.r1, startword, startword + strlen(startword));
-
-	for (r = s.r0; r < s.r1; r++){
-		if(utfrune(special, *r))
-			*s2.r1++ = '\\';
-		*s2.r1++ = *r;
-	}
-	s2.r1 += utftotext(s2.r1, endword, endword + strlen(endword));
-	return s2;
-}
-
-/* Look for the text in 'dot', if found, set '*r' and return true */
 Bool
 text_look(Text*t, Range *r, Range dot) {
 	RPath	buf;
@@ -70,44 +34,6 @@ text_look(Text*t, Range *r, Range dot) {
 	return text_findliteral(t, r, rstring(buf, buf + len));
 }
 
-/*
- * Used to find one "end" of an addr (which might be the whole addr, but
- * never mind).  The address passed in here is not expected to contain
- * commas.
- */
-static Bool
-findend(Text *t, Range *r, char *addr, Range dot)
-{
-	if(!strchr("/-#$.0123456789", *addr))
-		return false;
-
-	switch(*addr){
-	case '/':
-		strip_re_slash(addr);
-		return text_utfregexp(t, addr+1, r, true);
-	case '-':
-		if(addr[1] != '/')
-			return false;
-		strip_re_slash(addr);
-		return text_utfregexp(t, addr+2, r, 0);
-	case '#':
-		r->p0 = r->p1 = atol(addr + 1);
-		return r->p0 <= t->length;
-	case '$':
-		if(addr[1] != '\0')
-			return false;
-		*r = text_lastline(t);
-		return true;
-	case '.':
-		if(addr[1] != '\0')
-			return false;
-		*r = dot;
-		return true;
-	default:
-		return text_findline(t, r, atol(addr));
-	}
-}
-
 Bool
 text_findliteralutf(Text*t, Range *r, char*lit)
 {
@@ -214,3 +140,86 @@ text_search(Text *t, Range *r, char *addr, Range dot)
 	return true;
 }
 
+/*
+ * Used to find one "end" of an addr (which might be the whole addr, but
+ * never mind).  The address passed in here is not expected to contain
+ * commas.
+ */
+static Bool
+findend(Text *t, Range *r, char *addr, Range dot) {
+	if(!strchr("/-#$.0123456789", *addr))
+		return false;
+
+	switch(*addr){
+	case '/':
+		strip_re_slash(addr);
+		return text_utfregexp(t, addr+1, r, true);
+	case '-':
+		if(addr[1] != '/')
+			return false;
+		strip_re_slash(addr);
+		return text_utfregexp(t, addr+2, r, 0);
+	case '#':
+		r->p0 = r->p1 = atol(addr + 1);
+		return r->p0 <= t->length;
+	case '$':
+		if(addr[1] != '\0')
+			return false;
+		*r = text_lastline(t);
+		return true;
+	case '.':
+		if(addr[1] != '\0')
+			return false;
+		*r = dot;
+		return true;
+	default:
+		return text_findline(t, r, atol(addr));
+	}
+}
+
+/*
+ * Strip trailing slash from a regexp, if present and not escaped.
+ * WARNING: This code can reference the character
+ * immediately preceding its argument, so use with care.
+ */
+static void
+strip_re_slash(char *re) {
+	if ((re = strrchr(re, '/')) && re[1] == '\0' && re[-1] != '\\')
+		re[0] = '\0';
+}
+
+static Rstring
+literal(Rstring s) {
+	Rstring	s2;
+	Rune	*r;
+	
+	/* quote any special characters in 's' */
+	s2.r0 = s2.r1 = (Rune*)salloc(RSLEN(s)*2*sizeof(Rune));
+	for (r = s.r0; r < s.r1; r++){
+		if(utfrune(special, *r))
+			*s2.r1++ = '\\';
+		*s2.r1++ = *r;
+	}
+	return s2;
+}
+
+static Rstring
+word(Rstring s) {
+	Rstring	s2;
+	Rune	*r;
+	int	nrunes;
+	
+	nrunes = RSLEN(s)*2 +strlen(startword) + strlen(endword);
+	s2.r0 = s2.r1 = (Rune*)salloc(nrunes*sizeof(Rune));
+
+	s2.r1 += utftotext(s2.r1, startword, startword + strlen(startword));
+
+	for (r = s.r0; r < s.r1; r++){
+		if(utfrune(special, *r))
+			*s2.r1++ = '\\';
+		*s2.r1++ = *r;
+	}
+	s2.r1 += utftotext(s2.r1, endword, endword + strlen(endword));
+	return s2;
+}
+
