@@ -1,3 +1,7 @@
+/*******************************************
+ *	drag out a selection, scrolling as you go
+ *******************************************/
+
 #include "wily.h"
 #include "view.h"
 #include "text.h"
@@ -6,10 +10,10 @@ static void	frselectf2(Frame *f, Point p0, Point p1, Fcode c);
 static void	dclick(View *, ulong, ulong *, ulong *);
 
 typedef 	void		(*SelFn)(Frame*, Point, Point, Fcode);
-typedef enum Direction {UP,DOWN,NONE} Direction;
 
 #define BASE(v) ((v)->visible.p0)
 
+/* Return a-b, or 0 */
 static ulong
 usub (ulong a, ulong b)
 {
@@ -106,14 +110,16 @@ move(View *v, SelFn fn, Point pt, ulong p0, ulong p1) {
  * range.
  */
 static Range
-follow(View *v, ulong oldq, ulong p0, ulong p1, SelFn fn, Mouse *m)
+follow(View *v, ulong oldq, ulong p0, ulong p1, Bool selecting, Mouse *m)
 {
 	ulong	buttons = m->buttons;
 	Frame	*f = &v->f;
 	ulong	q;
 	Event	e;
 	ulong	type, timer=0;
-
+	SelFn 	fn;
+	
+	fn = selecting? frselectf : frselectf2;
 	toggle(v, fn, p0, p1);
 	v->selecting = true;
 	
@@ -122,20 +128,22 @@ follow(View *v, ulong oldq, ulong p0, ulong p1, SelFn fn, Mouse *m)
 	while(m->buttons == buttons){
 		q = frcharofpt(f, m->xy) +v->visible.p0;
 
-		/* We want the timer going iff we're outside the rectangle */
-		if (ptinrect(m->xy, f->r)) {
-			if (timer){
-				estoptimer(timer);
-				timer=0;
+		/* We only autoscroll while affecting the selection, not for b2 or b3 */
+		if (selecting) {	
+			/* We want the timer going iff we're outside the rectangle */
+			if (ptinrect(m->xy, f->r)) {
+				if (timer){
+					estoptimer(timer);
+					timer=0;
+				}
+			} else {
+				/* We do a move on timer events, or the first mouse event */
+				if(timer == type || timer == 0)
+					move(v, fn, m->xy, p0, p1);
+				if (timer==0)
+					timer = etimer(0, SCROLLTIME);
 			}
-		} else {
-			/* We do a move on timer events, or the first mouse event */
-			if(timer == type || timer == 0)
-				move(v, fn, m->xy, p0, p1);
-			if (timer==0)
-				timer = etimer(0, SCROLLTIME);
 		}
-
 		if(q != oldq && p1 != q){
 			update(v, fn, p0, p1, q);
 			oldq = p1 = q;
@@ -159,13 +167,11 @@ vselect(View *v, Mouse *m)
 	Frame	*f = &v->f;
 	Bool		selecting;	/* affects selection */
 	ulong	orig, p0, p1;
-	SelFn	fn;
 	Range	sel;
 
-	orig = p0 = p1  = frcharofpt(&v->f, m->xy) + BASE(v);
+	orig = p0 = p1  = frcharofpt(f, m->xy) + BASE(v);
 
 	selecting = m->buttons&LEFT;
-	fn = selecting? frselectf : frselectf2;
 
 	if (selecting) {
 		frselectp(f, F&~D);		/*remove old highlighted bit */
@@ -173,7 +179,7 @@ vselect(View *v, Mouse *m)
 		dclick(v, m->msec, &p0, &p1);
 	}
 
-	sel = follow(v, orig, p0, p1, fn, m);
+	sel = follow(v, orig, p0, p1, selecting, m);
 
 	if(selecting) {
 		v->sel = sel;
@@ -195,7 +201,7 @@ frselectf2(Frame *f, Point p0, Point p1, Fcode c)
 {
 	int n;
 	int ht;
-
+	
 	if(p0.x == f->left)
 		p0.x = f->r.min.x;
 	if(p1.x == f->left)
@@ -236,7 +242,6 @@ frselectf2(Frame *f, Point p0, Point p1, Fcode c)
 		bitblt(f->b, Pt(f->r.min.x, p0.y),
 				f->b, Rect(f->r.min.x, p0.y, p1.x, p1.y), c);
 	}
-
 }
 
 /* Check for double-click.  If 'click' happened not long after 'lastclick',
