@@ -1,3 +1,7 @@
+/*******************************************
+ *	Maintain and query (regexp, tag tools) pairs
+ *******************************************/
+
 #include "wily.h"
 #include <stdio.h>
 #include <sys/types.h>
