@@ -1,9 +1,3 @@
-#include "wily.h"
-#include "text.h"
-#include <ctype.h>
-
-static void	setgap(Text *t, ulong p, int n);
-
 /* We use a simple buffer-gap.  This is not too good for working
  * with large files if we're simultaneously working at both ends of
  * the file, because everytime we make a change, we have to move
@@ -20,6 +14,12 @@ static void	setgap(Text *t, ulong p, int n);
  * also be much more complex.  Virtual memory is our friend.
  */
 
+#include "wily.h"
+#include "text.h"
+#include <ctype.h>
+
+static void	setgap(Text *t, ulong p, int n);
+
 #ifndef NDEBUG
 static Rune *
 findnull(Rune*start, Rune*end)
@@ -44,7 +44,7 @@ text_invariants(Text *t)
 	assert(t->length <= t->alloced);
 	assert(!(p=findnull(t->text, t->text + t->gap.p0)));
 	assert(!(p=findnull(t->text + t->gap.p1, t->text + t->alloced)));
-	assert(! (t->isbody && !t->data) ); /* can't be body without data */
+	assert( TEXT_ISTAG(t) || t->data);  /* if we're not a tag, we have data */
 #endif
 	return true;
 }
@@ -60,8 +60,6 @@ text_read(Text *t, int fd, int len)
 	extern int utftotext_unconverted;
 	int	offset;
 	
-	/* return key_reader(fd, t->v);   removed experiment*/
-
 	/* Ensure we have enough rune space.  Do it one
 	 * block to avoid fragmentation
 	 */
@@ -222,10 +220,10 @@ text_replace(Text *t, Range r, Rstring s)
 	
 
 	if(t->data){
-		if(t->isbody)
-			data_sendreplace(t->data, r, s);
-		else
+		if(TEXT_ISTAG(t))
 			tag_modified(t, r.p0);
+		else
+			data_sendreplace(t->data, r, s);
 	}
 
 	r.p1 = r.p0 + rslen;
