@@ -6,6 +6,7 @@
  *
  * There may be one or more Views of a particular piece of text.
  */
+
 struct Text {
 	Rune	*text;		/* where we store stuff */
 	ulong	alloced,length;
@@ -21,16 +22,26 @@ struct Text {
 	enum {NoUndo, StartUndo, MoreUndo} undoing;
 };
 #define TEXT_ISTAG(t) (	!(t)->isbody	)
-#define TEXT_ISWINTAG(t) ((t)->v && (t)->v->win && TEXT_ISTAG(t))
-#define TCHAR(t,p) ((p)<(t)->gap.p0) ? (t)->text[(p)] : (t)->text[(p) + RLEN((t)->gap)]
 
-
-/* Get next rune, going forwards/backwards */
-#define	Tgetc(t)  ( ((t)->pos<(t)->gap.p0) ? ((t)->text[(t)->pos++] ) : (((t)->pos < (t)->length) ? (t)->text[(t)->pos++ + RLEN((t)->gap)] : -1))
+/* A set of macros to traverse all the runes within a text,
+ * useful for searching.
+ *
+ * To traverse forwards
+ *	Tgetcset(text, pos) sets a starting position
+ *	Tgetc(text) returns the next rune (or -1)
+ * To traverse backwards, use Tbgetcset(t,p), Tbgetc(t)
+ */
+#define Tgetcset(t,p) ((t)->pos = (p))
+#define	Tgetc(t)  ( \
+	((t)->pos < (t)->gap.p0) ? \
+		((t)->text[(t)->pos++] ) : \
+		(((t)->pos < (t)->length) ? \
+			(t)->text[(t)->pos++ + RLEN((t)->gap)] : \
+			-1))
 
 #define Tbgetc(tp) ( ((tp)->pos > (tp)->gap.p0) ? \
 	(tp)->text[--(tp)->pos + RLEN((tp)->gap)] : \
 	( (tp)->pos ? (tp)->text[--(tp)->pos] : -1) )
-
 #define Tbgetcset(t,p) ( (t)->pos = (p))
-#define Tgetcset(t,p) ((t)->pos = (p))
+
+/* TODO - a builtin literal search could be quite a bit quicker */
