@@ -1,3 +1,7 @@
+/*******************************************
+ *	Convenience wrappers around Text methods
+ *******************************************/
+
 #include "wily.h"
 #include "text.h"
 #include "view.h"
@@ -43,11 +47,11 @@ text_needsbackup(Text*t) {
 View*
 text_body(Text*t) {
 	if(t->data) {
-		if(t->isbody)
-			return t->v;
-		else {
+		if (TEXT_ISTAG(t)) {
 			t = data_body(t->data);
 			return t->v;
+		} else {
+			return t->v;
 		}
 	} else {
 		return 0;
@@ -189,7 +193,7 @@ text_autoindent(Text *t, ulong p)
 	buf[0] = '\n';
 	s.r0 = buf;
 
-	r = range(text_nl(t, p, 0), p);
+	r = range(text_startOfLine(t, p), p);
 	if (RLEN(r) > MAXAI)
 		r.p1 = r.p0 + MAXAI;
 	text_copy(t, r, buf +1);
@@ -218,7 +222,8 @@ back_height(Text *t, ulong p, Font *f, int width, int height) {
 	
 	if (p > 0) --p;
 	for( hpos = 0; p>0 && height>0; p--) {
-		c = TCHAR(t,p);
+		Tgetcset(t,p);
+		c = Tgetc(t);
 		switch(c) {
 		case '\t': hpos += tabsize; break;
 		case '\n': hpos = 0; height -= f->height; break;
