@@ -1,23 +1,18 @@
-#include "tile.h"
+/*******************************************
+ *	Tiling window manager
+ *******************************************/
 
-/* Return true if 'tile' represents a window that
- * should have its resize box filled in
- */
-Bool
-tile_isdirty(Tile*tile) {
-	return data_isdirty(view_data(tile->body));
-}
+#include "tile.h"
 
 /* Is the tile hidden? */
 Bool
-tile_hidden(Tile *t)
-{
+tile_hidden(Tile *t) {
+	/* We are hidden, or one of our ancestors is hidden */
 	return t->ishidden || (t->up && tile_hidden(t->up));
 }
 
 Bool
-tile_invariant(Tile *tile)
-{
+tile_invariant(Tile *tile) {
 	int	size ,body,tag, diff;
 	Tile	*last;
 
@@ -26,36 +21,42 @@ tile_invariant(Tile *tile)
 	/* Can't have _both_ a body and and a child */
 	assert(!(tile->body && tile->down));	
 
-	if (! tile->ishidden) {
-		size = TILESIZE(tile);
-		assert( size >= tile->base);
-		if ( tile->body ) {
+	if(tile->ishidden)
+		return true;
+		
+	/* Tests for non-hidden tiles */
+	size = TILESIZE(tile);
+	assert( size >= tile->base);
+	
+	if (!tile->body)
+		return true;
+	
+	/* Tests for tiles with bodies, i.e. windows */
 
-			/* The size of the tile == the sum of the sizes of its body and tag,
-			 * except if we're the "bottom" tile, in which case the size of the
-			* tile might be a _little_ bit bigger than that sum.
-			 */
-			body = view_height(tile->body);
-			tag = view_height(tile->tag);
-			last = last_visible_body(tile, 0);
+	/*
+         * The size of the tile == the sum of the sizes of its body and
+         * tag, except if we're the "bottom" tile, in which case the
+         * size of the tile might be a _little_ bit bigger than that
+         * sum.
+	 */
+	body = view_height(tile->body);
+	tag = view_height(tile->tag);
+	last = last_visible_body(tile, 0);
 
-			if (tile != last) {
-				assert(size == body + tag);
-			} else {
-				/* bottom tile might have a little 'slop' */
-				diff = size - (body + tag);
-				assert(diff >= 0);
-				assert (diff <= tag);
-			}
-		}
+	if (tile != last) {
+		assert(size == body + tag);
+	} else {
+		/* bottom tile might have a little 'slop' */
+		diff = size - (body + tag);
+		assert(diff >= 0);
+		assert (diff <= tag);
 	}
-
+	
 	return true;
 }
 
 Bool
-list_invariant(Tile *list)
-{
+list_invariant(Tile *list) {
 	int	prev;
 	Tile	*t;
 	int	diff;
@@ -86,8 +87,7 @@ list_invariant(Tile *list)
  * without increasing 't's size.
  */
 static void
-quantize(Tile*t)
-{
+quantize(Tile*t) {
 	int	tag, body,size;
 
 	if (!t->body)
@@ -103,8 +103,7 @@ quantize(Tile*t)
 
 /* Ensure 't' wil fit inside 'list'. */
 static void
-crop(Tile*t, Tile *list)
-{
+crop(Tile*t, Tile *list) {
 	int	size = TILESIZE(t);
 	int	listsize = LISTSIZE(list);
 
@@ -128,8 +127,7 @@ crop(Tile*t, Tile *list)
 
 /* 't's shape has changed.  Redisplay it, and any of its children */
 void
-tile_reshaped(Tile *t)
-{
+tile_reshaped(Tile *t) {
 	Rectangle r = rectangle(t);
 
 	assert(!t->ishidden);	/* we don't reshape hidden tiles */
@@ -150,8 +148,7 @@ tile_reshaped(Tile *t)
  * of space.
  */
 void
-list_add(Tile *list, Tile *tile)
-{
+list_add(Tile *list, Tile *tile) {
 	Tile	*left;
 	Tile	*next;
 	int	max;
@@ -196,7 +193,7 @@ list_add(Tile *list, Tile *tile)
 	next = next_visible(tile);
 	max = next? next->min : list->cmax;
 	tile->max = MAX(tile->max, max);
-		
+	tile->min = MIN(tile->max - tile->base, tile->min);
 	list_reshaped(list, tile);
 }
 
@@ -205,8 +202,7 @@ list_add(Tile *list, Tile *tile)
  * move 't' _too_ much.
  */
 static void
-adjust_position(Tile *t)
-{
+adjust_position(Tile *t) {
 	Tile	*l = t->up;
 	int	size, available, before, after, minsize, diff, move;
 
@@ -248,8 +244,7 @@ adjust_position(Tile *t)
 * tiles have the right approximate size, but that's it.
 */
 void
-list_reshaped(Tile *l, Tile *tile)
-{
+list_reshaped(Tile *l, Tile *tile) {
 	Tile	*t;
 	int	cmin, cmax;
 	Tile	*slop;
@@ -299,8 +294,7 @@ list_reshaped(Tile *l, Tile *tile)
  */
 /* Change the font of 't' and t's children */
 void
-tile_setfont(Tile *t,char* arg)
-{
+tile_setfont(Tile *t,char* arg) {
 	if(t->body) {
 		view_setfont( t->body, arg);
 	} else {
@@ -310,26 +304,12 @@ tile_setfont(Tile *t,char* arg)
 	}
 }
 
-int
-list_del(Tile*t)
-{
-	int	retval=0;
-
-	if(ISWIN(t)) {
-		retval =  win_del(t);
-	} else {
-		for(t=t->down; t; t=t->right)
-			if (list_del(t))
-				retval = -1;
-	}
-	if(!retval)
-		tile_del(t);
-	return retval;
-}
-
+/*
+ * Unlink 'tile' from its parent/child/siblings.
+ */
 void
-tile_del(Tile *tile)
-{
+tile_unlink(Tile*tile){
+	/* Unlink tile */
 	if(tile->right)
 		tile->right->left = tile->left;
 	if(tile->left) {
@@ -339,15 +319,36 @@ tile_del(Tile *tile)
 	} else {
 		tile->up->down = tile->right;
 	}
+	
 	list_unhide(tile->up);
 	cls(rectangle(tile));
 	list_reshaped(tile->up, 0);
 }
 
+/*
+ * Free up all the resources used by 'tile'
+ */
+void
+tile_free(Tile*tile){
+	/* Free tile's resources */
+	free(tile->body);
+	free(tile->tag);
+	free(tile);
+}
+
+/*
+ * Unlink 'tile' from its parent/child/siblings.
+ * Free up all the resources used by 'tile'
+ */
+void
+tile_del(Tile *tile) {
+	tile_unlink(tile);
+	tile_free(tile);
+}
+
 /* Find a new parent for 'tile' somewhere at point 'p' */
 Tile*
-newparent(Tile*tile, Point p)
-{
+newparent(Tile*tile, Point p){
 	Tile	*t = point2tile(wily, p);
 	assert(t);
 	while((t->ori == tile->ori) || t->body)
@@ -356,8 +357,7 @@ newparent(Tile*tile, Point p)
 }
 
 void
-tile_move(Tile *tile, Point p)
-{
+tile_move(Tile *tile, Point p){
 	Tile	*parent;
 	int	dest;
 
@@ -366,7 +366,7 @@ tile_move(Tile *tile, Point p)
 	if (parent == 0 || parent == wily)
 		return;
 
-	tile_del(tile);
+	tile_unlink(tile);
 	dest = (tile->ori == H) ? p.x : p.y;
 	if (tile->min < dest && dest < tile->max)
 		tile->min = dest;
@@ -392,8 +392,7 @@ tile_body(Tile*t) {
 }
 
 View*
-tile_tag(Tile*t)
-{
+tile_tag(Tile*t) {
 	return t? t->tag: 0;
 }
 
