@@ -1,3 +1,7 @@
+/*******************************************
+ *	Maintain Undo chains, Undo methods
+ *******************************************/
+
 #include "wily.h"
 #include "text.h"
 
