@@ -1,3 +1,7 @@
+/*******************************************
+ *	A few utilities
+ *******************************************/
+
 #include "wily.h"
 #include <stdio.h>
 #include <stdarg.h>
@@ -107,7 +111,7 @@ backup_name(char *orig, char *back)
 	if(!(dirp = opendir(dir))) {
 		return diag(0, "couldn't opendir %s", dir);
 	}
-	rewinddir(dirp);	/* Workaround for possible FreeBSD bug. */
+	rewinddir(dirp);	/* Workaround for FreeBSD. */
 	while ((direntp = readdir(dirp))) {
 		if ( (n=atoi(direntp->d_name)) > max)
 			max = n;
@@ -414,6 +418,11 @@ frame_isfull(Frame*f)
 Bool	utfHadNulls;
 int	utftotext_unconverted;	/* bytes at the end which weren't converted */
 
+/* Convert UTF from s1 to s2 into runes, store them at r
+ * Returns the number of runes stored.
+ * Sets utfHadNulls to indicate that some of the UTF contained nulls,
+ * which are _not_ converted into null Runes.
+ */
 ulong
 utftotext(Rune *r, char *s1, char *s2)
 {
