@@ -1,3 +1,7 @@
+/*******************************************
+ *	view size and reshaping
+ *******************************************/
+
 #include "wily.h"
 #include "view.h"
 
@@ -165,8 +169,7 @@ button_set(View *v) {
 	assert(ISTAG(v));	/* we're a tag */
 	r = resizebox(v->r);
 	border(&screen, r, 1, F);
-
-	if( tile_isdirty(v->tile))
+	if(data_isdirty(view_data(tile_body(v->tile))))
 		rfill(r, F);
 }
 
