@@ -1,9 +1,27 @@
+/*******************************************
+ *	View methods
+ *******************************************/
+
 #include "wily.h"
 #include "view.h"
 #include <ctype.h>
 
 static Rectangle nullrect = { {0,0}, {0,0}};
 
+/* Store string representation of 'dot' for 'v' into 'buf'.
+ * if 'isLine', we want a line address, otherwise we want
+ * a character address.
+ */
+void
+view_getdot(View *v, char*buf, Bool isLine) {
+	if(isLine) {
+		sprintf(buf, " :%d,.", text_linenumber(v->t, v->sel.p0));
+	} else {
+		/* character address */
+		sprintf(buf, " :#%lu,.", v->sel.p0);
+	}
+}
+
 Range
 view_expand(View *v, Range r, char *s) {
 	if(RLEN(r))
@@ -47,8 +65,7 @@ view_new(Font *f, Bool istag, Text *text, Tile *tile)
 
 /* Delete v and free its resources.  Return 0 for success */
 int
-view_delete(View *v)
-{
+view_delete(View *v){
 	if (text_rmview(v->t, v))
 		return -1;
 	if(v==last_selection)
