@@ -1,3 +1,7 @@
+/*******************************************
+ *	b3-type stuff in a view
+ *******************************************/
+
 #include "wily.h"
 #include "view.h"
 
@@ -30,6 +34,9 @@ view_look (View *v, char *arg) {
 
 	assert(ISBODY(v));
 
+	if( ! text_length(v->t))
+		return ;
+
 	p = (v->sel.p0 + 1) % text_length(v->t);
 	r = range(p, p);
 
@@ -144,58 +151,58 @@ view_literal(View**vp, Range*r, char*s) {
 }
 
 /*
- * Search for address 's'.  Use *vp for context, *r as the starting point
+ * Search for address 'a'.  Use *vp for context, *r as the starting point
  * for searches.  May create a new window, but doesn't otherwise affect
  * the screen.  If it finds something, update *vp and *r and return
- * true, otherwise return false and leave vp and r alone
+ * true, otherwise return false and leave vp and r alone.
  *
  * 's' may be of the form path:addr, or path, or :addr.
  */
 static Bool
-view_gotofile(View**vp, Range *r, char *s) {
+view_gotofile(View**vp, Range *r, char *a) {
+	Path	s;
 	View	*v = *vp;
 	View	*v2;
-	char	*addr;
 	char *colon;	/* preserve the colon */
 	Path	label;
 
+	strcpy(s,a);		/* BUG - fails horribly if 'a' is large */
 	colon = strchr(s, ':');
 	if (colon) {
-		addr = colon + 1;
 		*colon=0;
-	}else
-		addr = 0;
+	}
 
 	/* look for 's' as a file or directory */
 	if(strlen(s)) {
+		/* 'path' or 'path:addr' */
 		data_addcontext(view_data(v), label, s);
-		if(colon)
-			*colon=':';
 		if( (v2=openlabel(label, false))){
-			*vp = v = v2;
-			*r = v->sel;
-			if(!addr)
-				return true;	/* "label" */
-		} else if (addr)
-			return false;	/* label:addr, bad path */
+			if(colon) {
+				Range oldr = v2->sel;
+				
+				if(!text_search(v2->t, r, colon+1, v2->sel)) {
+					*r = oldr;
+				}
+			} else {
+				*r = v2->sel;
+			}
+			*vp = v2;
+			return true;
+		} else 
+			return false;	/* bad path */
 	}
-	/*
-         * If we get this far, either we didn't find a matching file, or
-         * we still have to evaluate an address.
-	 */
-	 if(colon)
-	 	*colon = ':';
-	if(!addr)
-		return false;
-	
+	assert(!strlen(s));
+
 	/* :addr by itself then */
 	if(!ISBODY(v)){
 		if( ! ((v = view_body(v)) || (v = view_body(last_selection))) )
 			return false;
-		*vp = v;
- 		*r = v->sel;
 	}
-
-	return text_search(v->t, r, addr, v->sel);
+	*r = v->sel;
+	if (text_search(v->t, r, colon+1, v->sel)) {
+		*vp = v;
+ 		return true;
+	} 
+	return false;
 }
 
