@@ -1,3 +1,7 @@
+/*******************************************
+ *	view scrolling
+ *******************************************/
+
 #include "wily.h"
 #include "view.h"
 
@@ -132,7 +136,7 @@ view_show(View *v, Range r) {
 
 		if (!RINTERSECT(r, v->visible)) {
 			/* lines are too long, quit being fancy, start with line contain 'r' */
-			dest = text_nl(v->t, r.p0, 0);
+			dest = text_startOfLine(v->t, r.p0);
 			view_set(v,dest);
 		}
 		if (!RINTERSECT(r, v->visible)) {
@@ -180,7 +184,7 @@ view_scroll(View *v, Mouse *m) {
 		break;
 	default:
 		runepos = (text_length(v->t) * y) / Dy(v->f.r);
-		n = text_nl(v->t, runepos, 0);
+		n = text_startOfLine(v->t, runepos);
 		view_set(v, n);
 		if (runepos > v->visible.p1) {
 			view_set(v, runepos);
