@@ -1,3 +1,7 @@
+/*******************************************
+ *	main(), parse arguments
+ *******************************************/
+
 #include "wily.h"
 #include "tile.h"
  
@@ -5,11 +9,17 @@ static int	ncolumns = 2;
 int	tagheight;
 Tile	*wily=0;			/* encloses the whole application */
 
-char *wilytools = 	"Kill | Newcol Quit Putall wily-0.13.33 Dotfiles Font ";
+char *wilytools = 	"Kill | Newcol Quit Putall wily-0.13.41 Dotfiles Font "; /* version */
 char *filetools = 	"Del Look .";
-char *dirtools = 	"Del Get Look ..";
+char *dirtools = 	"Del Look ..";
 char *columntools = "Delcol New Cut Paste Snarf Anchor Split | ";
 
+void
+_allocerror(char*s){
+	fprintf(stderr,"%s\n", s);
+	abort();
+}
+
 /* Add  'cmd' to the visible list of running processes. */
 void
 addrunning(char *cmd){
